UninstallEntry

Struct UninstallEntry 

pub struct UninstallEntry {
    pub display_name: String,
    pub version: String,
    pub publisher: String,
    pub install_location: Option<String>,
    pub quiet_uninstall_string: Option<String>,
    pub uninstall_string: Option<String>,
}
Snapshot of one uninstall registry entry.

Fields

display_name: String

Application display name.

version: String

Application version string, if the registry entry exposes one.

publisher: String

Publisher string, if the registry entry exposes one.

install_location: Option<String>

Install location stored in the registry, if present.

quiet_uninstall_string: Option<String>

Quiet uninstall command stored in the registry, if present.

uninstall_string: Option<String>

Standard uninstall command stored in the registry, if present.