pub struct UninstallEntry {
pub display_name: String,
pub version: String,
pub publisher: String,
pub install_location: Option<String>,
pub quiet_uninstall_string: Option<String>,
pub uninstall_string: Option<String>,
}Expand description
Snapshot of one uninstall registry entry.
Fields
display_name: StringApplication display name.
version: StringApplication version string, if the registry entry exposes one.
publisher: StringPublisher string, if the registry entry exposes one.
install_location: Option<String>Install location stored in the registry, if present.
quiet_uninstall_string: Option<String>Quiet uninstall command stored in the registry, if present.
uninstall_string: Option<String>Standard uninstall command stored in the registry, if present.